#### Run Menu

Sequence:

This feature is like the feature launched by the '>>' icon button in the icon tool bar. Its tool tip reads, " Display each selected image in turn in the text cropping dialog and store its cropped text in the CropLog table." (The status line at the bottom also shows help for each menu item and button.) The only difference is that it will only display the image files in the list that have been checked. Selecting them using the mouse on the file path itself will not include them.

Batch:

Like the "Sequence" feature in the same menu, this will operate on all files in the image file list that are selected using the checkbox. The difference is that it will extract all of the text from each in turn without showing a dialog and will store the extracted text in a record in the BatchMaster table in the TextExtraction.db database. The file's path is one of the fields stored, but since it is not the key field, multiple extractions from the same file will have separate records with different time stamps. This allows you to check for modifications of image files over time, such a might occur if there is tampering with them. The fields stored in the record include the time-stamp of the extraction process, the full file path, the text extracted, and in the info field the 'stat' of the file at the time the text was extracted. This is simply the file meta-data available from the operating system, which includes such items as the last modified time-stamp, the file size, and the access restrictions.

An alternative is to use the button on the icon tool bar with the circular arrow icon and the help text, "Extract all text from all files in the list and store it in the BatchMaster table ." This ignores both the check boxes and any list selections you might have made and simply extracts all text from all of the files in the list. This should be used with caution as depending on the number of files in the list, this could take a long time. Basic progress will be displayed on in the console. For more detailed and complete reporting, use the Jobs definition and running features.

Job:

Use this feature to select and run a job that you defined using the Admin -> Jobs main menu selection or the toolbox icon button in the icon tool bar. These launch the "Job Definition" dialog in which you can select files and folders to include in any order in a sequence or batch and then save the job for use later under a name you provide. You cash also specify a job type, although this feature is not yet developed to the point where a list of already entered job types are displayed for your selection in this dialog. Once you have reviewed the help on how to define a job, come back to this page to see how one is run.

When you select this menu item, a dialog with the title "Select and RUN Job" will be launched. It displays a list of the names of jobs that you have defined from which you can select one to run. There are two modes in which you can run a job: Sequence, and Batch. These work like the Sequence and Batch selections previously described for this Run menu (above). Batch mode has an additional feature available. If you select Batch from the menu button labelled "Run Mode:" at the top, A help message displays at the bottom along with a Console Output configuration panel. Since Batch Jobs can take significant time to run, you can select the items you want displayed as each file is processed by the text extraction engine. Selecting "File Path" will provide s count of the files processed along with the full path of each file as it is processed. Selecting "Times and Durations" will also display the start and end time for each file along with the time it took to extract the text. This also provides the start and end times for the entire batch and its duration. Choosing "Statistics" only provides the byte count of the text extracted currently, although more is possible in the future depending on interest. Selecting "Text Extracted" should be used with caution since it will cause the entire text extracted to be written go the console after the other items selected have been displayed.

Like the rest of the application, all of the buttons and other controls have brief help displayed in their tool tips and at the same time in the status bar at the bottom.